@@ -4,7 +4,10 @@ use MooseX::StrictConstructor;
 
 with 'IM::Engine::HasEngine';
 
+sub post_initialization { }
+
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
